#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-L5I2HZvTSBJ2wSn9bBMNZ8
key:                  dhall-lsp-server-1.1.4-L5I2HZvTSBJ2wSn9bBMNZ8
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  208d14ef865b4ee083474e535ca1f198
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-L5I2HZvTSBJ2wSn9bBMNZ8
depends:
    aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY
    aeson-pretty-0.8.10-CtOF5yzA90t5fWHc997lbJ base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-3CUAWo0ZrT017RrHeSToiu
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dhall-1.42.3-2oV19Moq7HbK04rMwP0Ch
    dhall-json-1.7.12-AbNKsGh2BwFH7MJy5lWXzM directory-1.3.8.5
    filepath-1.4.300.1 lens-5.3.4-CkqmOXVchFg1U8XPLp3M2a
    lsp-2.2.0.0-3J7slxQP1ui8QijUPoiGpE
    megaparsec-9.7.0-ANIQXwq4KPSJ1jjmaOZNxr mtl-2.3.1
    network-uri-2.6.4.2-JVtNAVx4uuKIiYA1iZNoT1
    prettyprinter-1.7.1-LD9ksSCydFQDqbwXyaukvW text-2.0.2
    text-rope-0.3-AbOSPWrPz0yIUUa2OLVnoe transformers-0.6.1.0
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    uri-encode-1.5.0.7-yEuOYGzgSG9vMOjeXNOKH

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

